=================================================================
``psyclone.domain.nemo.transformations.create_nemo_kernel_trans``
=================================================================

.. automodule:: psyclone.domain.nemo.transformations.create_nemo_kernel_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.create_nemo_kernel_trans


Classes
=======

- :py:class:`CreateNemoKernelTrans`:
  Transform a generic PSyIR Schedule representing a loop body into a NEMO


.. autoclass:: CreateNemoKernelTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: CreateNemoKernelTrans
      :parts: 1
